<?php

/**
 * @author: VLThemes
 * @version: 2.0.3
 */

define( 'FOLIM_THEME_DIRECTORY', esc_url( trailingslashit( get_template_directory_uri() ) ) );
define( 'FOLIM_REQUIRE_DIRECTORY', trailingslashit( get_template_directory() ) );
define( 'FOLIM_DEVELOPMENT', false );

/**
 * After setup
 */
if ( ! function_exists( 'folim_setup' ) ) {
	function folim_setup() {

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Folim, use a find and replace
		 * to change 'folim' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'folim', get_template_directory() . '/languages' );
		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 1920, 9999 );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Add support for responsive embedded content.
		add_theme_support( 'responsive-embeds' );

		// Add custom editor font sizes.
		add_theme_support(
			'editor-font-sizes',
			array(
				array(
					'name' => esc_html__( 'Small', 'folim' ),
					'shortName' => esc_html__( 'S', 'folim' ),
					'size' => 12,
					'slug' => 'small',
				),
				array(
					'name' => esc_html__( 'Normal', 'folim' ),
					'shortName' => esc_html__( 'M', 'folim' ),
					'size' => 14,
					'slug' => 'normal',
				),
				array(
					'name' => esc_html__( 'Large', 'folim' ),
					'shortName' => esc_html__( 'L', 'folim' ),
					'size' => 22,
					'slug' => 'large',
				),
				array(
					'name' => esc_html__( 'Huge', 'folim' ),
					'shortName' => esc_html__( 'XL', 'folim' ),
					'size' => 25,
					'slug' => 'huge',
				),
			)
		);

		// Editor color palette.
		add_theme_support( 'editor-color-palette', array(
			array(
				'name' => esc_html__( 'Black', 'folim' ),
				'slug' => 'black',
				'color' => '#101010',
			),
			array(
				'name' => esc_html__( 'Gray', 'folim' ),
				'slug' => 'gray',
				'color' => '#eeeeee',
			),
			array(
				'name' => esc_html__( 'White', 'folim' ),
				'slug' => 'white',
				'color' => '#ffffff',
			)
		) );

		// Register nav menus
		register_nav_menus( array(
			'primary-menu' => esc_html__( 'Primary Menu', 'folim' ),
			'footer-menu' => esc_html__( 'Footer Menu', 'folim' )
		) );

		add_image_size( 'folim-1140x500_crop', 1140, 500, true );
		add_image_size( 'folim-1140x735_crop', 1140, 735, true );
		add_image_size( 'folim-720x560_crop', 720, 560, true );
		add_image_size( 'folim-720x480_crop', 720, 480, true );
		add_image_size( 'folim-1920x1080', 1920 );
		add_image_size( 'folim-160x140_crop', 160, 140, true );

	}
}
add_action( 'after_setup_theme', 'folim_setup' );

/**
 * Content width
 */
if ( ! function_exists( 'folim_content_width' ) ) {
	function folim_content_width() {
		$GLOBALS['content_width'] = apply_filters( 'folim/content_width', 1920 );
	}
}
add_action( 'after_setup_theme', 'folim_content_width', 0 );

/**
 * Import ACF fields
 */
if ( ! FOLIM_DEVELOPMENT ) {
	function folim_acf_show_admin_panel() {
		return apply_filters( 'folim/acf_show_admin_panel', false );
	}
	add_filter( 'acf/settings/show_admin', 'folim_acf_show_admin_panel' );
}

if ( ! FOLIM_DEVELOPMENT ) {
	require_once FOLIM_REQUIRE_DIRECTORY . 'inc/helper/custom-fields/custom-fields.php';
}

if ( ! function_exists( 'folim_acf_save_json' ) ) {
	function folim_acf_save_json( $path ) {
		$path = FOLIM_REQUIRE_DIRECTORY . 'inc/helper/custom-fields';
		return $path;
	}
}
add_filter( 'acf/settings/save_json', 'folim_acf_save_json' );

if ( FOLIM_DEVELOPMENT ) {
	if ( ! function_exists( 'folim_acf_load_json' ) ) {
		function folim_acf_load_json( $paths ) {
			unset( $paths[0] );
			$paths[] = FOLIM_REQUIRE_DIRECTORY . 'inc/helper/custom-fields';
			return $paths;
		}
	}
	add_filter( 'acf/settings/load_json', 'folim_acf_load_json' );
}

/**
 * Include Kirki fields
 */
require_once FOLIM_REQUIRE_DIRECTORY . 'inc/framework/customizer-helper.php';
require_once FOLIM_REQUIRE_DIRECTORY . 'inc/framework/customizer.php';
require_once FOLIM_REQUIRE_DIRECTORY . 'inc/framework/customizer-dynamic-css.php';

/**
 * Required files
 */
$folim_theme_includes = array(
	'required-plugins',
	'enqueue',
	'includes',
	'demo-import',
	'functions',
	'actions',
	'filters',
	'menus',
	'portfolio',
	'elementor'
);

foreach ( $folim_theme_includes as $file ) {
	require_once FOLIM_REQUIRE_DIRECTORY . 'inc/theme-' . $file . '.php';
}

// Unset the global variable.
unset( $folim_theme_includes );