<?php

/**
 * @author: VLThemes
 * @version: 2.0.3
 */

$priority = 0;

/**
 * General fonts
 */
VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'primary_font',
	'section' => 'typography_fonts',
	'label' => esc_html__( 'Primary Font', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'choices' => apply_filters(
		'vlthemes_fonts_choices', [
			'variant' => [
				'regular',
				'500',
				'600',
				'700',
			]
		]
	),
	'default' => array(
		'font-family' => 'Dosis'
	),
	'output' => array(
		array(
			'choice' => 'font-family',
			'element' => ':root',
			'property' => '--vlt-primary-font',
			'context' => array( 'editor', 'front' ),
		)
	)
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'secondary_font',
	'section' => 'typography_fonts',
	'label' => esc_html__( 'Secondary Font', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'choices' => apply_filters(
		'vlthemes_fonts_choices', [
			'variant' => [
				'regular',
				'600',
				'700',
			]
		]
	),
	'default' => array(
		'font-family' => 'Source Sans Pro'
	),
	'output' => array(
		array(
			'choice' => 'font-family',
			'element' => ':root',
			'property' => '--vlt-secondary-font',
			'context' => array( 'editor', 'front' ),
		)

	)
) );

/**
 * Body typography
 */
VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'text_typography',
	'section' => 'typography_text',
	'label' => esc_html__( 'Text Typography', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'choices' => apply_filters(
		'vlthemes_fonts_choices', [
			'variant' => [
				'regular',
				'600',
				'700',
			]
		]
	),
	'default' => array(
		'font-family' => 'Source Sans Pro',
		'variant' => 'regular',
		'font-size' => '0.875rem', // 14px
		'line-height' => '1.6',
		'color' => '#606060',
		'letter-spacing' => '0',
		'text-transform' => 'none'
	),
	'output' => array(
		array(
			'element' => 'body'
		),
		array(
			'element' => '.edit-post-visual-editor.editor-styles-wrapper',
			'context' => array( 'editor' ),
		),
	)
) );

/**
 * Heading typography
 */
VLT_Options::add_field( array(
	'type' => 'custom',
	'settings' => 'th_1',
	'section' => 'typography_headings',
	'default' => '<div class="kirki-separator">' . esc_html__( 'H1 Titles', 'folim' ) . '</div>',
	'priority' => $priority++,
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h1_titles',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-desktop" style="margin-right: 5px;"></span>' . esc_html__( 'Desktop', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'choices' => apply_filters(
		'vlthemes_fonts_choices', [
			'variant' => [
				'regular',
				'500',
				'600',
				'700',
			]
		]
	),
	'default' => array(
		'font-family' => 'Dosis',
		'variant' => '500',
		'font-size' => '1.5625rem', // 25px
		'line-height' => '1.5',
		'color' => '#404040',
		'letter-spacing' => '2px',
		'text-transform' => 'none'
	),
	'output' => array(
		array(
			'element' => 'h1, .h1'
		),
		array(
			'element' => '.editor-block-list__block h1, .wp-block-heading h1.editor-rich-text__tinymce, .editor-post-title__block .editor-post-title__input',
			'context' => array( 'editor' ),
		),
	)
) );


VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h1_titles_tablet',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-tablet" style="margin-right: 5px;"></span>' . esc_html__( 'Tablet', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'default' => array(
		'font-size' => '1.5625rem', // 25px
		'line-height' => '1.5',
	),
	'output' => array(
		array(
			'element' => 'h1, .h1',
			'media_query' => '@media (max-width: 767px)'
		)
	)
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h1_titles_phone',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-smartphone" style="margin-right: 5px;"></span>' . esc_html__( 'Phone', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'default' => array(
		'font-size' => '1.5625rem', // 25px
		'line-height' => '1.5',
	),
	'output' => array(
		array(
			'element' => 'h1, .h1',
			'media_query' => '@media (max-width: 575px)'
		)
	)
) );

VLT_Options::add_field( array(
	'type' => 'custom',
	'settings' => 'th_2',
	'section' => 'typography_headings',
	'default' => '<div class="kirki-separator">' . esc_html__( 'H2 Titles', 'folim' ) . '</div>',
	'priority' => $priority++,
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h2_titles',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-desktop" style="margin-right: 5px;"></span>' . esc_html__( 'Desktop', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'choices' => apply_filters(
		'vlthemes_fonts_choices', [
			'variant' => [
				'regular',
				'500',
				'600',
				'700',
			]
		]
	),
	'default' => array(
		'font-family' => 'Dosis',
		'variant' => '500',
		'font-size' => '1.375rem', // 22px
		'line-height' => '1.5',
		'color' => '#404040',
		'letter-spacing' => '2px',
		'text-transform' => 'none'
	),
	'output' => array(
		array(
			'element' => 'h2, .h2'
		),
		array(
			'element' => '.editor-block-list__block h2, .wp-block-heading h2.editor-rich-text__tinymce',
			'context' => array( 'editor' ),
		),
	)
) );


VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h2_titles_tablet',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-tablet" style="margin-right: 5px;"></span>' . esc_html__( 'Tablet', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'default' => array(
		'font-size' => '1.375rem', // 22px
		'line-height' => '1.5',
	),
	'output' => array(
		array(
			'element' => 'h2, .h2',
			'media_query' => '@media (max-width: 767px)'
		)
	)
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h2_titles_phone',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-smartphone" style="margin-right: 5px;"></span>' . esc_html__( 'Phone', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'default' => array(
		'font-size' => '1.375rem', // 22px
		'line-height' => '1.5',
	),
	'output' => array(
		array(
			'element' => 'h2, .h2',
			'media_query' => '@media (max-width: 575px)'
		)
	)
) );

VLT_Options::add_field( array(
	'type' => 'custom',
	'settings' => 'th_3',
	'section' => 'typography_headings',
	'default' => '<div class="kirki-separator">' . esc_html__( 'H3 Titles', 'folim' ) . '</div>',
	'priority' => $priority++,
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h3_titles',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-desktop" style="margin-right: 5px;"></span>' . esc_html__( 'Desktop', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'choices' => apply_filters(
		'vlthemes_fonts_choices', [
			'variant' => [
				'regular',
				'500',
				'600',
				'700',
			]
		]
	),
	'default' => array(
		'font-family' => 'Dosis',
		'variant' => '500',
		'font-size' => '1.25rem', // 20px
		'line-height' => '1.5',
		'color' => '#404040',
		'letter-spacing' => '2px',
		'text-transform' => 'none'
	),
	'output' => array(
		array(
			'element' => 'h3, .h3'
		),
		array(
			'element' => '.editor-block-list__block h3, .wp-block-heading h3.editor-rich-text__tinymce',
			'context' => array( 'editor' ),
		),
	)
) );


VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h3_titles_tablet',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-tablet" style="margin-right: 5px;"></span>' . esc_html__( 'Tablet', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'default' => array(
		'font-size' => '1.25rem', // 20px
		'line-height' => '1.5',
	),
	'output' => array(
		array(
			'element' => 'h3, .h3',
			'media_query' => '@media (max-width: 767px)'
		)
	)
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h3_titles_phone',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-smartphone" style="margin-right: 5px;"></span>' . esc_html__( 'Phone', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'default' => array(
		'font-size' => '1.25rem', // 20px
		'line-height' => '1.5',
	),
	'output' => array(
		array(
			'element' => 'h3, .h3',
			'media_query' => '@media (max-width: 575px)'
		)
	)
) );

VLT_Options::add_field( array(
	'type' => 'custom',
	'settings' => 'th_4',
	'section' => 'typography_headings',
	'default' => '<div class="kirki-separator">' . esc_html__( 'H4 Titles', 'folim' ) . '</div>',
	'priority' => $priority++,
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h4_titles',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-desktop" style="margin-right: 5px;"></span>' . esc_html__( 'Desktop', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'choices' => apply_filters(
		'vlthemes_fonts_choices', [
			'variant' => [
				'regular',
				'500',
				'600',
				'700',
			]
		]
	),
	'default' => array(
		'font-family' => 'Dosis',
		'variant' => '500',
		'font-size' => '1rem', // 16px
		'line-height' => '1.5',
		'color' => '#404040',
		'letter-spacing' => '2px',
		'text-transform' => 'none'
	),
	'output' => array(
		array(
			'element' => 'h4, .h4'
		),
		array(
			'element' => '.editor-block-list__block h4, .wp-block-heading h4.editor-rich-text__tinymce',
			'context' => array( 'editor' ),
		),
	)
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h4_titles_tablet',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-tablet" style="margin-right: 5px;"></span>' . esc_html__( 'Tablet', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'default' => array(
		'font-size' => '1rem', // 16px
		'line-height' => '1.5',
	),
	'output' => array(
		array(
			'element' => 'h4, .h4',
			'media_query' => '@media (max-width: 767px)'
		)
	)
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h4_titles_phone',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-smartphone" style="margin-right: 5px;"></span>' . esc_html__( 'Phone', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'default' => array(
		'font-size' => '1rem', // 16px
		'line-height' => '1.5',
	),
	'output' => array(
		array(
			'element' => 'h4, .h4',
			'media_query' => '@media (max-width: 575px)'
		)
	)
) );

VLT_Options::add_field( array(
	'type' => 'custom',
	'settings' => 'th_5',
	'section' => 'typography_headings',
	'default' => '<div class="kirki-separator">' . esc_html__( 'H5 Titles', 'folim' ) . '</div>',
	'priority' => $priority++,
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h5_titles',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-desktop" style="margin-right: 5px;"></span>' . esc_html__( 'Desktop', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'choices' => apply_filters(
		'vlthemes_fonts_choices', [
			'variant' => [
				'regular',
				'500',
				'600',
				'700',
			]
		]
	),
	'default' => array(
		'font-family' => 'Dosis',
		'variant' => '500',
		'font-size' => '0.9375rem', // 15px
		'line-height' => '1.5',
		'color' => '#404040',
		'letter-spacing' => '2px',
		'text-transform' => 'none'
	),
	'output' => array(
		array(
			'element' => 'h5, .h5'
		),
		array(
			'element' => '.editor-block-list__block h5, .wp-block-heading h5.editor-rich-text__tinymce',
			'context' => array( 'editor' ),
		),
	)
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h5_titles_tablet',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-tablet" style="margin-right: 5px;"></span>' . esc_html__( 'Tablet', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'default' => array(
		'font-size' => '0.9375rem', // 15px
		'line-height' => '1.5',
	),
	'output' => array(
		array(
			'element' => 'h5, .h5',
			'media_query' => '@media (max-width: 767px)'
		)
	)
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h5_titles_phone',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-smartphone" style="margin-right: 5px;"></span>' . esc_html__( 'Phone', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'default' => array(
		'font-size' => '0.9375rem', // 15px
		'line-height' => '1.5',
	),
	'output' => array(
		array(
			'element' => 'h5, .h5',
			'media_query' => '@media (max-width: 575px)'
		)
	)
) );

VLT_Options::add_field( array(
	'type' => 'custom',
	'settings' => 'th_6',
	'section' => 'typography_headings',
	'default' => '<div class="kirki-separator">' . esc_html__( 'H6 Titles', 'folim' ) . '</div>',
	'priority' => $priority++,
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h6_titles',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-desktop" style="margin-right: 5px;"></span>' . esc_html__( 'Desktop', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'choices' => apply_filters(
		'vlthemes_fonts_choices', [
			'variant' => [
				'regular',
				'500',
				'600',
				'700',
			]
		]
	),
	'default' => array(
		'font-family' => 'Dosis',
		'variant' => '500',
		'font-size' => '0.8125rem', // 13px
		'line-height' => '1.5',
		'color' => '#404040',
		'letter-spacing' => '2px',
		'text-transform' => 'none'
	),
	'output' => array(
		array(
			'element' => 'h6, .h6'
		),
		array(
			'element' => '.editor-block-list__block h6, .wp-block-heading h6.editor-rich-text__tinymce',
			'context' => array( 'editor' ),
		),
	)
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h6_titles_tablet',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-tablet" style="margin-right: 5px;"></span>' . esc_html__( 'Tablet', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'default' => array(
		'font-size' => '0.8125rem', // 13px
		'line-height' => '1.5',
	),
	'output' => array(
		array(
			'element' => 'h6, .h6',
			'media_query' => '@media (max-width: 767px)'
		)
	)
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_h6_titles_phone',
	'section' => 'typography_headings',
	'label' => '<span class="dashicons dashicons-smartphone" style="margin-right: 5px;"></span>' . esc_html__( 'Phone', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'default' => array(
		'font-size' => '0.8125rem', // 13px
		'line-height' => '1.5',
	),
	'output' => array(
		array(
			'element' => 'h6, .h6',
			'media_query' => '@media (max-width: 575px)'
		)
	)
) );

/**
 * Blockquote typography
 */
VLT_Options::add_field( array(
	'type' => 'custom',
	'settings' => 'tb_1',
	'section' => 'typography_blockquote',
	'default' => '<div class="kirki-separator">' . esc_html__( 'Blockquote', 'folim' ) . '</div>',
	'priority' => $priority++,
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'blockquote_typography',
	'section' => 'typography_blockquote',
	'label' => '<span class="dashicons dashicons-desktop" style="margin-right: 5px;"></span>' . esc_html__( 'Desktop', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'choices' => apply_filters(
		'vlthemes_fonts_choices', [
			'variant' => [
				'regular',
				'600',
				'700',
			]
		]
	),
	'default' => array(
		'font-family' => 'Source Sans Pro',
		'variant' => 'regular',
		'font-size' => '0.875rem', // 14px
		'line-height' => '1.6',
		'color' => '#606060',
		'letter-spacing' => '0',
		'text-transform' => 'none'
	),
	'output' => array(
		array(
			'element' => 'blockquote'
		),
		array(
			'element' => '.wp-block-quote, .wp-block-pullquote',
			'context' => array( 'editor' ),
		),
	)
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'blockquote_typography_tablet',
	'section' => 'typography_blockquote',
	'label' => '<span class="dashicons dashicons-tablet" style="margin-right: 5px;"></span>' . esc_html__( 'Tablet', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'default' => array(
		'font-size' => '0.875rem', // 14px
		'line-height' => '1.6',
	),
	'output' => array(
		array(
			'element' => 'blockquote',
			'media_query' => '@media (max-width: 767px)'
		)
	)
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'blockquote_typography_phone',
	'section' => 'typography_blockquote',
	'label' => '<span class="dashicons dashicons-smartphone" style="margin-right: 5px;"></span>' . esc_html__( 'Phone', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'default' => array(
		'font-size' => '0.875rem', // 14px
		'line-height' => '1.6',
	),
	'output' => array(
		array(
			'element' => 'blockquote',
			'media_query' => '@media (max-width: 575px)'
		)
	)
) );

/**
 * Button typography
 */
VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_button',
	'section' => 'typography_buttons',
	'label' => esc_html__( 'Button Typography', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'choices' => apply_filters(
		'vlthemes_fonts_choices', [
			'variant' => [
				'regular',
				'500',
				'600',
				'700',
			]
		]
	),
	'default' => array(
		'font-family' => 'Dosis',
		'variant' => '500',
		'font-size' => '0.9375rem', // 15px
		'line-height' => '1',
		'letter-spacing' => '1px',
		'text-transform' => 'none'
	),
	'output' => array(
		array(
			'element' => '.vlt-btn'
		)
	)
) );

/**
 * Input typography
 */
VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_input',
	'section' => 'typography_input',
	'label' => esc_html__( 'Input Typography', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'choices' => apply_filters(
		'vlthemes_fonts_choices', [
			'variant' => [
				'regular',
				'500',
				'600',
				'700',
			]
		]
	),
	'default' => array(
		'font-family' => 'Dosis',
		'variant' => 'regular',
		'font-size' => '0.9375rem', // 15px
		'letter-spacing' => '1px',
		'color' => '#404040',
		'line-height' => 'inherit',
		'text-transform' => 'none'
	),
	'output' => array(
		array(
			'element' => '
				input[type="text"],
				input[type="email"],
				input[type="password"],
				input[type="tel"],
				input[type="url"],
				input[type="search"],
				input[type="number"],
				textarea,
				select,
				.select2
				'
		)
	)
) );

VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_label',
	'section' => 'typography_input',
	'label' => esc_html__( 'Label Typography', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'choices' => apply_filters(
		'vlthemes_fonts_choices', [
			'variant' => [
				'regular',
				'500',
				'600',
				'700',
			]
		]
	),
	'default' => array(
		'font-family' => 'Dosis',
		'variant' => '500',
		'font-size' => '0.875rem', // 14px
		'line-height' => '1.5',
		'color' => '#505050',
		'letter-spacing' => '2px',
		'text-transform' => 'uppercase'
	),
	'output' => array(
		array(
			'element' => 'label'
		)
	)
) );

/**
 * Widget title typography
 */
VLT_Options::add_field( array(
	'type' => 'typography',
	'settings' => 'typography_widget_title',
	'section' => 'typography_widget',
	'label' => esc_html__( 'Widget Title Typography', 'folim' ),
	'priority' => $priority++,
	'transport' => 'auto',
	'choices' => apply_filters(
		'vlthemes_fonts_choices', [
			'variant' => [
				'regular',
				'500',
				'600',
				'700',
			]
		]
	),
	'default' => array(
		'font-family' => 'Dosis',
		'variant' => '600',
		'font-size' => '1.125rem', // 18px
		'line-height' => '1.1',
		'color' => '#404040',
		'letter-spacing' => '2px',
		'text-transform' => 'uppercase'
	),
	'output' => array(
		array(
			'element' => '.vlt-widget__title'
		)
	)
) );