<?php

/**
 * @author: VLThemes
 * @version: 2.0.3
 */

/**
 * Register sidebars
 */
if ( ! function_exists( 'folim_register_sidebar' ) ) {
	function folim_register_sidebar() {

		register_sidebar( array(
			'name' => esc_html__( 'Blog Sidebar', 'folim' ),
			'id' => 'blog_sidebar',
			'description' => esc_html__( 'Blog Widget Area', 'folim' ),
			'before_widget' => '<div id="%1$s" class="vlt-widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h5 class="vlt-widget__title">',
			'after_title' => '</h5>'
		) );

		register_sidebar( array(
			'name' => esc_html__( 'Aside Sidebar', 'folim' ),
			'id' => 'aside_sidebar',
			'description' => esc_html__( 'Aside Widget Area', 'folim' ),
			'before_widget' => '<div id="%1$s" class="vlt-widget vlt-widget--white %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h5 class="vlt-widget__title">',
			'after_title' => '</h5>'
		) );

		$footer_columns = folim_get_theme_mod( 'footer_columns' );

		for ( $i = 1; $i < $footer_columns + 1; $i++ ) {
			register_sidebar(array(
				'name' => sprintf( esc_html__( 'Footer Sidebar: %s Column', 'folim' ), $i ),
				'id' => sanitize_key( 'footer_sidebar_' . $i ),
				'description' => esc_html__( 'Footer Widget Area', 'folim' ),
				'before_widget' => '<div id="%1$s" class="vlt-widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h5 class="vlt-widget__title">',
				'after_title' => '</h5>'
			));
		}

		// custom sidebars
		if ( folim_get_theme_mod( 'custom_sidebars' ) ) {
			foreach ( folim_get_theme_mod( 'custom_sidebars' ) as $sidebar ) {
				if ( ! empty( $sidebar[ 'sidebar_title' ] && ! empty( $sidebar[ 'sidebar_description' ] ) ) ) {
					register_sidebar( array(
						'name' => esc_html( $sidebar[ 'sidebar_title' ] ),
						'id' => strtolower( trim( preg_replace( '/[^A-Za-z0-9-]+/', '_', $sidebar[ 'sidebar_title' ] ) ) ),
						'description' => esc_html( $sidebar[ 'sidebar_description' ] ),
						'before_widget' => '<div id="%1$s" class="vlt-widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h5 class="vlt-widget__title">',
						'after_title' => '</h5>'
					) );
				}
			}
		}

	}
}
add_action( 'widgets_init', 'folim_register_sidebar' );

/**
 * Site preloader
 */
if ( ! function_exists( 'folim_site_preloader' ) ) {
	function folim_site_preloader() {
		$class = 'vlt-entry-site';

		if ( folim_get_theme_mod( 'show_preloader' ) == 'show' ) {
			switch ( folim_get_theme_mod( 'preloader_style' ) ) {
				case 'cube':
					echo '<div class="vlt-site-preloader"><div class="vlt-site-preloader__inner"><div class="cube"><span></span><span></span><span></span><span></span></div></div></div>';
					break;
				case 'signal':
					echo '<div class="vlt-site-preloader"><div class="vlt-site-preloader__inner"><div class="signal"><span></span><span></span><span></span><span></span><span></span></div></div></div>';
					break;
				case 'spinner':
					echo '<div class="vlt-site-preloader"><div class="vlt-site-preloader__inner"><div class="spinner"><span></span></span></div></div></div>';
					break;
				case 'image':
					echo '<div class="vlt-site-preloader"><div class="vlt-site-preloader__inner"><img src="' . folim_get_theme_mod( 'preloader_image' ) . '" alt="' . get_bloginfo( 'name' ) . '"></div></div>';
					break;
			}
		}

	}
}
add_action( 'wp_body_open', 'folim_site_preloader' );

/**
 * Change admin logo
 */
if ( ! function_exists( 'folim_change_admin_logo' ) ) {
	function folim_change_admin_logo() {
		if ( ! folim_get_theme_mod( 'login_logo_image' ) ) {
			return;
		}
		$image_url = folim_get_theme_mod( 'login_logo_image' );
		$image_w = folim_get_theme_mod( 'login_logo_image_width' );
		$image_h = folim_get_theme_mod( 'login_logo_image_height' );
		echo '<style type="text/css">
			h1 a {
				background: transparent url(' . esc_url( $image_url ) . ') 50% 50% no-repeat !important;
				width:' . esc_attr( $image_w ) . '!important;
				height:' . esc_attr( $image_h ) . '!important;
				background-size: cover !important;
			}
		</style>';
	}
}
add_action( 'login_head', 'folim_change_admin_logo' );

/**
 * Prints Tracking code
 */
if ( ! function_exists( 'folim_print_tracking_code' ) ) {
	function folim_print_tracking_code() {
		$tracking_code = folim_get_theme_mod( 'tracking_code' );
		if ( ! empty( $tracking_code ) ) {
			echo '' . $tracking_code;
		}
	}
}
add_action( 'wp_head', 'folim_print_tracking_code' );