<?php

/**
 * @author: VLThemes
 * @version: 2.0.3
 */

/**
 * Demo import
*/
if ( ! function_exists( 'folim_demo_import_files' ) ) {
	function folim_demo_import_files() {
		return array(
			array(
				'import_file_name' => esc_html__( 'Demo Import', 'folim' ),
				'local_import_file' => FOLIM_REQUIRE_DIRECTORY . 'inc/demo/demo-content.xml',
				'local_import_widget_file' => FOLIM_REQUIRE_DIRECTORY . 'inc/demo/widgets.wie',
				'local_import_customizer_file' => FOLIM_REQUIRE_DIRECTORY . 'inc/demo/customizer.dat'
			),
		);
	}
}
add_filter( 'pt-ocdi/import_files', 'folim_demo_import_files' );

/**
 * Disable regenerate thumbnails
 */
add_filter( 'pt-ocdi/regenerate_thumbnails_in_content_import', '__return_false' );

if ( ! function_exists( 'folim_after_import_setup' ) ) {
	function folim_after_import_setup() {

		global $wp_rewrite;

		// Set menus
		$primary_menu = get_term_by( 'name', 'Primary Menu', 'nav_menu' );
		$footer_menu = get_term_by( 'name', 'Footer Menu', 'nav_menu' );

		set_theme_mod( 'nav_menu_locations',
			array(
				'primary-menu' => $primary_menu->term_id,
				'footer-menu' => $footer_menu->term_id,
			)
		);

		// Set pages
		$front_page_id = get_page_by_title( 'Homepage 01' );
		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );

		// Update permalink
		$wp_rewrite->set_permalink_structure( '/%postname%/' );

		// Update option
		update_option( 'date_format', 'd M, Y' );

		// Import Revolution Slider
		if ( class_exists( 'RevSlider' ) ) {
			$revo_slider = new RevSlider();
			$slider_aliases = $revo_slider->getAllSliderAliases();
			$slider_array = array(
				'vlthemes-slider-01',
				'vlthemes-slider-02',
				'vlthemes-slider-03',
				'vlthemes-slider-04',
				'vlthemes-slider-05',
				'vlthemes-slider-06'
			);

			foreach ( $slider_array as $slider ) {
				if ( ! in_array( $slider, $slider_aliases ) ) {
					$path = FOLIM_REQUIRE_DIRECTORY . 'inc/demo/sliders/' . $slider . '.zip';
					if ( file_exists( $path ) ) {
						$revo_slider->importSliderFromPost( true, true, $path );
					}
				}
			}

		}

		// Set default vars for Elementor
		if( class_exists( '\Elementor\Plugin' ) ) {
			$kit = \Elementor\Plugin::$instance->kits_manager->get_active_kit_for_frontend();
			$kit->update_settings( [
				'container_width' => [
					'size' => '1140',
					'unit' => 'px'
				],
				'space_between_widgets' => [
					'column' => '0',
					'row' => '0',
					'unit' => 'px'
				],
				'global_image_lightbox' => '',
			] );
			\Elementor\Plugin::$instance->files_manager->clear_cache();
		}

		// Set default options for Elementor
		$elementor_options = array(
			'elementor_experiment-container' => 'active',
			'elementor_experiment-container_grid' => 'active',
			'elementor_experiment-e_swiper_latest' => 'inactive',
			'elementor_experiment-e_optimized_css_loading' => 'inactive',
			'elementor_experiment-e_font_icon_svg' => 'inactive',
			'elementor_unfiltered_files_upload' => true,
			'elementor_disable_color_schemes' => 'yes',
			'elementor_disable_typography_schemes' => 'yes'
		);

		foreach( $elementor_options as $key => $value ) {
			update_option( $key, $value );
		}

		$cpt_support = get_option( 'elementor_cpt_support' );

		// Check if option DOESN'T exist in db
		if ( ! $cpt_support ) {
			$cpt_support = [ 'page', 'post', 'portfolio', 'product' ]; // create array of our default supported post types
			update_option( 'elementor_cpt_support', $cpt_support ); // write it to the database
		}

		// If it DOES exist, but portfolio is NOT defined
		else if ( ! in_array( 'portfolio', $cpt_support ) ) {
			$cpt_support[] = 'portfolio'; // append to array
			update_option( 'elementor_cpt_support', $cpt_support ); // update database
		}

	}
}
add_action( 'pt-ocdi/after_import', 'folim_after_import_setup' );