<?php

/**
 * @author: VLThemes
 * @version: 2.0.3
 */

/**
 * ACF in Admin Panel
 */
if ( ! function_exists( 'folim_acf_in_admin_panel' ) ) {
	function folim_acf_in_admin_panel() {
		return folim_get_theme_mod( 'acf_show_admin_panel' ) == 'show' ? true : false;
	}
}
add_filter( 'folim/acf_show_admin_panel', 'folim_acf_in_admin_panel' );


/**
 * Add body class
 */
if ( ! function_exists( 'folim_add_body_class' ) ) {
	function folim_add_body_class( $classes ) {
		$classes[] = '';
		if ( ! wp_is_mobile() ) {
			$classes[] = 'no-mobile';
		} else {
			$classes[] = 'is-mobile';
		}

		return $classes;
	}
}
add_filter( 'body_class', 'folim_add_body_class' );

/**
 * Add html class
 */
if ( ! function_exists( 'folim_add_html_class' ) ) {
	function folim_add_html_class( $classes = '' ) {

		// header
		$acf_header = folim_get_theme_mod( 'page_custom_navigation', true );
		$classes .= ' vlt-is--header-' . folim_get_theme_mod( 'navigation_type', $acf_header );

		// footer
		$acf_footer = folim_get_theme_mod( 'page_custom_footer', true );
		$classes .= ' vlt-is--footer-' . folim_get_theme_mod( 'footer_template', $acf_footer );
		if ( folim_get_theme_mod( 'footer_fixed', $acf_footer ) == 'enable' ) {
			$classes .= ' vlt-is--footer-fixed';
		}

		return apply_filters( 'folim/add_html_class', folim_sanitize_class( $classes ) );

	}
}

/**
 * Get post password form
 */
if ( ! function_exists( 'folim_get_post_password_form' ) ) {
	function folim_get_post_password_form() {
		global $post;
		$label = 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );
		$output = '<form class="vlt-post-password-form" action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post">';
		$output .= '<p>'.esc_html__( 'This content is restricted access, please type the password below and get access.', 'folim' ).'</p>';
		$output .= '<div class="vlt-form-group m-0">';
		$output .= '<input name="post_password" id="' . $label . '" type="password" size="20" placeholder="' . esc_attr__( 'Password:' , 'folim' ) . '">';
		$output .= '<input type="submit" name="Submit" class="vlt-btn vlt-btn--secondary vlt-btn--block" value="' . esc_attr__( 'GET ACCESS' , 'folim' ) . '">';
		$output .= '</div>';
		$output .= '</form>';
		return apply_filters( 'folim/post_password', $output );
	}
}
add_filter( 'the_password_form', 'folim_get_post_password_form' );

/**
 * Admin logo link
 */
if ( ! function_exists( 'folim_change_admin_logo_link' ) ) {
	function folim_change_admin_logo_link() {
		return home_url( '/' );
	}
}
add_filter( 'login_headerurl', 'folim_change_admin_logo_link' );

/**
 * Add comma to tag widget
 */
if ( ! function_exists( 'folim_filter_tag_cloud' ) ) {
	function folim_filter_tag_cloud( $args ) {
		$args['smallest'] = 0.9375; // 15px
		$args['largest'] = 0.9375; // 15px
		$args['unit'] = 'rem';
		$args['orderby'] = 'count';
		$args['order'] = 'DESC';
		$args['separator']= '';
		return $args;
	}
}
add_filter ( 'widget_tag_cloud_args', 'folim_filter_tag_cloud' );

/**
 * Function that adds classes on body for version of the theme
 */
if ( ! function_exists( 'folim_theme_version_class' ) ) {
	function folim_theme_version_class( $classes ) {
		$current_theme = wp_get_theme();
		$theme_prefix = 'vlt';
		// is child theme activated?
		if ( $current_theme->parent() ) {
			// add child theme version
			$classes[] = $theme_prefix . '-child-theme-version-' . $current_theme->get( 'Version' );
			// get parent theme
			$current_theme = $current_theme->parent();
		}
		if ( $current_theme->exists() && $current_theme->get( 'Version' ) != '' ) {
			$classes[] = $theme_prefix . '-theme-version-' . $current_theme->get( 'Version' );
			$classes[] = $theme_prefix . '-theme-' . strtolower( $current_theme->get( 'Name' ) );
		}
		return $classes;
	}
}
add_filter( 'body_class', 'folim_theme_version_class' );

/**
 * Disable Kirki Telemetry
 */
add_filter( 'kirki_telemetry', '__return_false' );

/**
 * Remove cf7 autop
 */
add_filter( 'wpcf7_autop_or_not', '__return_false' );

/**
 * Comment form fields order
 */
if ( ! function_exists( 'folim_comment_form_fields' ) ) {
	function folim_comment_form_fields( $comment_fields ) {
		if ( folim_get_theme_mod( 'comment_placement' ) == 'bottom' ) {
			$keys = array_keys( $comment_fields );
			if ( 'comment' == $keys[0] ) {
				$comment_fields['comment'] = array_shift( $comment_fields );
			}
		}
		return $comment_fields;
	}
}
add_filter( 'comment_form_fields', 'folim_comment_form_fields' );

/**
 * Override Elementor template
 */
add_filter( 'template_include', function( $template ) {
	if ( false !== strpos( $template, '/templates/canvas.php' ) ) {
		$template = FOLIM_REQUIRE_DIRECTORY . 'template-canvas-page.php';
	}
	return $template;
}, 12 );
