<?php

/**
 * @author: VLThemes
 * @version: 2.0.3
 */

/**
 * Wrapper function to deal with backwards compatibility.
 */
if ( ! function_exists( 'folim_body_open' ) ) {
	function folim_body_open() {
		if ( function_exists( 'wp_body_open' ) ) {
			wp_body_open();
		} else {
			do_action( 'wp_body_open' );
		}
	}
}

/**
 * Sanitize slass tag
 */
if ( ! function_exists( 'folim_sanitize_class' ) ) {
	function folim_sanitize_class( $class, $fallback = null ) {

		if ( is_string( $class ) ) {
			$class = explode( ' ', $class );
		}

		if ( is_array( $class ) && count( $class ) > 0 ) {
			$class = array_map( 'sanitize_html_class', $class );
			return implode( ' ', $class );
		} else {
			return sanitize_html_class( $class, $fallback );
		}

	}
}

/**
 * Sanitize style tag
 */
if ( ! function_exists( 'folim_sanitize_style' ) ) {
	function folim_sanitize_style( $style ) {

		$allowed_html = array(
			'style' => array ()
		);
		return wp_kses( $style, $allowed_html );

	}
}

/**
 * Get trimmed content
 */
if ( ! function_exists( 'folim_get_trimmed_content' ) ) {
	function folim_get_trimmed_content( $max_words = 18 ) {

		global $post;

		$content = $post->post_excerpt != '' ? $post->post_excerpt : $post->post_content;
		$content = preg_replace( '~(?:\[/?)[^/\]]+/?\]~s', '', $content );
		$content = strip_tags( $content );
		$content = strip_shortcodes( $content );
		$words = explode( ' ', $content, $max_words + 1 );
		if ( count( $words ) > $max_words ) {
			array_pop( $words );
			array_push( $words, '...', '' );
		}
		$content = implode( ' ', $words );
		$content = esc_html( $content );

		return apply_filters( 'folim/get_trimmed_content', $content );

	}
}

/**
 * Get page pagination
 */
if ( ! function_exists( 'folim_get_page_pagination' ) ) {
	function folim_get_page_pagination( $query = null, $paginated = 'numeric' ) {

		if ( $query == null ) {
			global $wp_query;
			$query = $wp_query;
		}

		$page  = $query->query_vars[ 'paged' ];
		$pages = $query->max_num_pages;
		$paged = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : ( get_query_var( 'page' ) ? get_query_var( 'page' ) : 1 );

		if ( $page == 0 ) {
			$page = 1;
		}
		if ( $paginated == 'none' || $pages <= 1 ) {
			return;
		}

		$class = 'vlt-pagination';
		$class .= ' vlt-pagination--' . $paginated;

		$output = '<nav class="' . folim_sanitize_class( $class ) . '">';

		if ( $pages > 1 ) {

			if ( $paginated == 'paged' ) {

				if ( $page - 1 >= 1 ) {
					$output .= '<a class="prev" href="' . get_pagenum_link( $page + 1 ) . '"><span>' . esc_html__( 'Previous', 'folim' ) . '</span><i class="fa-regular fa-angles-left"></i></a>';
				} else {
					$output .= '<span class="prev"><i class="fa-regular fa-angles-left"></i></span>';
				}

				if ( $page + 1 <= $pages ) {
					$output .= '<a class="next" href="' . get_pagenum_link( $page + 1 ) . '"><i class="fa-regular fa-angles-right"></i><span>' . esc_html__( 'Next', 'folim' ) . '</span></a>';
				} else {
					$output .= '<span class="next"><i class="fa-regular fa-angles-right"></i></span>';
				}

			}

			if ( $paginated == 'numeric' ) {

				$numeric_links = paginate_links( array(
					'type' => 'array',
					'foramt' => '',
					'add_args' => '',
					'current' => $paged,
					'total' => $pages,
					'prev_text' => '<span>' . esc_html__( 'Previous', 'folim' ) . '</span><i class="fa-regular fa-angles-left"></i>',
					'next_text' => '<i class="fa-regular fa-angles-right"></i><span>' . esc_html__( 'Next', 'folim' ) . '</span>',
				) );

				$output .= '<ul>';
				if ( is_array( $numeric_links ) ) {
					foreach ( $numeric_links as $numeric_link ) {
						$output .= '<li>'. $numeric_link .'</li>';
					}
				}
				$output .= '</ul>';

			}

		}
		$output .= '</nav>';
		return apply_filters( 'folim/get_page_pagination', $output );
	}
}

/**
 * Get post taxonomy
 */
if ( ! function_exists( 'folim_get_post_taxonomy' ) ) {
	function folim_get_post_taxonomy( $post_id, $taxonomy, $delimiter = ', ', $get = 'name', $link = true ) {

		$tags = wp_get_post_terms( $post_id, $taxonomy );
		$list = '';

		foreach ( $tags as $tag ) {
			if ( $link ) {
				$list .= '<a href="' . get_category_link( $tag->term_id ) . '">' . $tag->$get . '</a>' . $delimiter;
			} else {
				$list .= $tag->$get . $delimiter;
			}
		}

		return substr( $list, 0, strlen( $delimiter ) * ( -1 ) );

	}
}

/**
 * Reading time
 */
if ( ! function_exists( 'folim_get_reading_time' ) ) {
	function folim_get_reading_time() {
		global $post;
		$wpm = 200;
		$words = str_word_count( strip_tags( $post->post_content ) );
		$minutes = floor( $words / $wpm );
		if ( 1 <= $minutes ) {
			$output = $minutes . esc_html__( ' min read', 'folim' );
		} else {
			$output = esc_html__( '1 min read', 'folim' );
		}
		return apply_filters( 'folim/get_reading_time', $output );
	}
}

/**
 * Custom comment
 */
if ( ! function_exists( 'folim_custom_comment' ) ) {
	function folim_custom_comment( $comment, $args, $depth ) {

		$GLOBALS['comment'] = $comment;
		global $post;

		$author_class = 'vlt-comment-name';
		if ( $comment->user_id === $post->post_author ) {
			$author_class .= ' comment-author';
		}

		?>

		<li <?php comment_class( 'vlt-comment-item' ); ?>>

			<div class="vlt-comment-item__inner" id="comment-<?php comment_ID(); ?>">

				<?php if ( 0 != $args['avatar_size'] && get_avatar( $comment ) ) : ?>
					<a class="vlt-comment-avatar" href="<?php echo get_comment_author_url(); ?>"><?php echo get_avatar( $comment, $args['avatar_size'], '', '', array( 'extra_attr' => 'loading=lazy' ) ); ?></a>
					<!-- /.vlt-comment-avatar -->
				<?php endif; ?>

				<div class="vlt-comment-content">

					<div class="vlt-comment-header">

						<h5 class="<?php echo folim_sanitize_class( $author_class ); ?>">
							<?php comment_author(); ?>
						</h5>

						<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID, $args ) ); ?>" class="vlt-comment-metas">
							<time datetime="<?php comment_time( 'c' ); ?>">
								<?php printf( get_comment_date() ); ?>
							</time>
						</a>

					</div>

					<div class="vlt-comment-text vlt-content-markup">

						<?php comment_text(); ?>

						<?php if ( '0' == $comment->comment_approved ): ?>
							<div class="vlt-alert-message">
								<?php esc_html_e( 'Your comment is awaiting moderation.', 'folim' ); ?>
							</div>
						<?php endif; ?>

					</div>

					<ul class="vlt-comment-buttons">

						<?php edit_comment_link( esc_html__( 'Edit', 'folim' ), '<li>', '</li>' ); ?>

						<?php

							comment_reply_link( array_merge( $args, array(
								'depth' => $depth,
								'max_depth' => $args['max_depth'],
								'before' => '<li>',
								'after' => '</li>'
							) ) );

						?>

					</ul>

				</div>

			</div>

		<!-- </li> is added by WordPress automatically -->
		<?php
	}
}

/**
 * Comment navigation
 */
if ( ! function_exists( 'folim_get_comment_navigation()' ) ) {
	function folim_get_comment_navigation() {

		$output = '';

		if ( get_comment_pages_count() > 1 ):
			$output .= '<div class="vlt-comments-navigation">';
			if ( get_previous_comments_link() ) {
				add_filter( 'previous_comments_link_attributes', function() {
					return 'class="prev-page"';
				} );
				$output .= get_previous_comments_link( '<i class="fa-regular fa-angles-left"></i>' . esc_html__( 'Prev Page', 'folim' ) );
			} else {
				$output .= '<span class="prev-page inactive"><i class="fa-regular fa-angles-left"></i>'.esc_html__( 'Prev Page', 'folim' ).'</span>';
			}
			if ( get_next_comments_link() ) {
				add_filter( 'next_comments_link_attributes', function() {
					return 'class="next-page"';
				} );
				$output .= get_next_comments_link( esc_html__( 'Next Page', 'folim' ) . '<i class="fa-regular fa-angles-right"></i>' );
			} else {
				$output .= '<span class="next-page inactive">'.esc_html__( 'Next Page', 'folim' ).'<i class="fa-regular fa-angles-right"></i></span>';
			}
			$output .= '</div>';
		endif;

		return apply_filters( 'folim/comment_pagination', $output );

	}
}

/**
 * Portfolio navigation
 */
if ( ! function_exists( 'folim_get_portfolio_navigation' ) ) {
	function folim_get_portfolio_navigation() {

		$nextPost = get_adjacent_post( false, '', true );
		$prevPost = get_adjacent_post( false, '', false );

		$output = '';

		$output .= '<div class="vlt-portfolio-navigation">';
		$output .= '<div class="container">';
		$output .= '<div class="row align-items-center">';

		$output .= '<div class="col-5">';
		if ( ! empty( $prevPost ) ) {
			$output .= '<span>' . esc_html__( 'Prev Work', 'folim' ).'</span>';
			$output .= '<h5><a class="prev-work" href="' . get_permalink( $prevPost->ID ) . '">' . get_the_title( $prevPost->ID ) . '</a></h5>';
		}
		$output .= '</div>';

		$output .= '<div class="col-2 text-center lh-1">';
		if ( get_theme_mod( 'portfolio_link' ) ) {
			$output .= '<a class="all-works" href="' . get_permalink( get_theme_mod( 'portfolio_link' ) ) . '"><span></span><span></span><span></span><span></span></a>';
		}
		$output .= '</div>';

		$output .= '<div class="col-5 text-end">';
		if ( ! empty( $nextPost ) ) {
			$output .= '<span>'.esc_html__( 'Next Work', 'folim' ).'</span>';
			$output .= '<h5><a class="next-work" href="' .get_permalink( $nextPost->ID ).'">' . get_the_title( $nextPost->ID ) . '</a></h5>';
		}
		$output .= '</div>';

		$output .= '</div>';
		$output .= '</div>';
		$output .= '</div>';

		return apply_filters( 'folim/get_portfolio_navigation', $output );

	}
}

/**
 * Page navigation
 */
if ( ! function_exists( 'folim_get_page_navigation' ) ) {
	function folim_get_page_navigation() {

		$nextPost = get_adjacent_post( false, '', true );
		$prevPost = get_adjacent_post( false, '', false );
		$output = '';

		if ( empty( $prevPost ) && empty( $nextPost ) ) {
			return;
		}

		$output .= '<div class="vlt-page-navigation">';
		$output .= '<div class="row">';

		$output .= '<div class="col-md-6">';
		if ( !empty( $prevPost ) ) {
			$output .= '<div class="prev clearfix">';
			$output .= '<a href="' . get_permalink( $prevPost->ID ) . '"><i class="fa-regular fa-angles-left"></i></a>';
			$output .= '</div>';
		}
		$output .= '</div>';

		$output .= '<div class="col-md-6">';
		if ( !empty( $nextPost ) ) {
			$output .= '<div class="next clearfix">';
			$output .= '<a href="' . get_permalink( $nextPost->ID ) . '"><i class="fa-regular fa-angles-right"></i></a>';
			$output .= '</div>';
		}
		$output .= '</div>';

		$output .= '</div>';
		$output .= '</div>';

		return apply_filters( 'folim/get_post_navigation', $output );
	}
}

/**
 * Post views
 */
if ( ! function_exists( 'folim_set_post_views' ) ) {
	function folim_set_post_views( $postID ) {

		$count_key = 'folim_post_views_count';
		$count = get_post_meta( $postID, $count_key, true );
		if ( $count == '' ) {
			$count = 0;
			delete_post_meta( $postID, $count_key );
			add_post_meta( $postID, $count_key, '0' );
		} else {
			$count++;
			update_post_meta( $postID, $count_key, $count );
		}

	}
}
add_action( 'wp_head', 'folim_track_post_views' );

if ( ! function_exists( 'folim_track_post_views' ) ) {
	function folim_track_post_views( $postID ) {

		if ( !is_single() ) {
			return;
		}
		if ( empty( $postID ) ) {
			global $post;
			$postID = $post->ID;
		}
		folim_set_post_views( $postID );

	}
}

if ( ! function_exists( 'folim_get_post_views' ) ) {
	function folim_get_post_views( $postID ) {
		$count_key = 'folim_post_views_count';
		$count = get_post_meta( $postID, $count_key, true );
		if ( $count == '' ) {
			delete_post_meta( $postID, $count_key );
			add_post_meta( $postID, $count_key, '0' );
			return '0';
		}
		return $count;
	}
}

/**
 * Render elementor template
 */
if ( ! function_exists( 'folim_render_elementor_template' ) ) {
	function folim_render_elementor_template( $template ) {

		if ( ! $template ) {
			return;
		}

		if ( 'publish' !== get_post_status( $template ) ) {
			return;
		}

		return \Elementor\Plugin::$instance->frontend->get_builder_content_for_display( $template, true );

	}
}